==> quanyi-center-api-0.0.35-20231126.095400-31-sources.jar: cn/com/duiba/quanyi/center/api/dto/ccbLife/CcbLifeSettlementDetailDto.java <==
package cn.com.duiba.quanyi.center.api.dto.ccbLife;

import java.io.Serializable;
import java.util.Date;
import lombok.Data;

/**
 * 商户表
 * @author mybatis generator 
 * @date 2023-11-23
 */
@Data
public class CcbLifeSettlementDetailDto implements Serializable {
     
    private static final long serialVersionUID = 17007078913754384L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;

    /**
     * 商户号
     */
    private String businessNum;

    /**
     * 门店号
     */
    private String shopNum;

    /**
     * 商户名
     */
    private String businessName;

    /**
     * 优惠券id
     */
    private String thirdCouponId;

    /**
     * 优惠券名称
     */
    private String thirdCouponName;

    /**
     * 用户id
     */
    private String thirdUserId;

    /**
     * 卡号
     */
    private String cardNo;

    /**
     * 领券时间
     */
    private String drawCouponTime;

    /**
     * 核销时间
     */
    private String verificationTime;

    /**
     * 核销订单号
     */
    private String verificationOrderNum;

    /**
     * 订单总共金额
     */
    private Long orderTotalPrice;

    /**
     * 本次消费优惠金额
     */
    private Long discountAmount;

    /**
     * 支付方式
     */
    private String payChannel;

    /**
     * 核销商户号
     */
    private String verificationMch;

    /**
     * 核销来源渠道号
     */
    private String verificationChannelNo;

    /**
     * 优惠券生效时间
     */
    private String couponEffectTime;

    /**
     * 优惠券失效时间
     */
    private String couponNoeffectTime;

    /**
     * 核销人
     */
    private String verificationUser;

    /**
     * 领券用户手机号
     */
    private String drawCouponPhone;

    /**
     * 实际消费优惠金额
     */
    private Long actualConsumeDiscountAmount;

    /**
     * 最低使用消费限制
     */
    private Long lowestUsageLimit;

    /**
     * 卡bin类型
     */
    private String cardBinType;

    /**
     * 是否是银联类型
     */
    private String unionpayType;

    /**
     * 是否清算
     */
    private String clearType;

    /**
     * 清算金额
     */
    private Long clearAmount;

    /**
     * 二级分行
     */
    private String secondLevelBranch;

    /**
     * 商家补贴总金额
     */
    private Long merchantSubsidyAmount;

    /**
     * 机构补贴总金额
     */
    private Long institutionalSubsidyAmount;

    /**
     * 导入文件id
     */
    private Long uploadFileId;

    /**
     * 删除标识 （0：未删除，1：删除）默认为0
     */
    private Byte deleted;

    /**
     * 年和月份
     */
    private Long yearAndMonth;
}

==> quanyi-center-api-1.2.8-sources.jar: cn/com/duiba/quanyi/center/api/dto/ccbLife/CcbLifeSettlementDetailDto.java <==
package cn.com.duiba.quanyi.center.api.dto.ccbLife;

import java.io.Serializable;
import java.util.Date;
import lombok.Data;

/**
 * 商户表
 * @author mybatis generator 
 * @date 2023-11-23
 */
@Data
public class CcbLifeSettlementDetailDto implements Serializable {
     
    private static final long serialVersionUID = 17007078913754384L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;

    /**
     * 商户号
     */
    private String businessNum;

    /**
     * 门店号
     */
    private String shopNum;

    /**
     * 商户名
     */
    private String businessName;

    /**
     * 优惠券id
     */
    private String thirdCouponId;

    /**
     * 优惠券名称
     */
    private String thirdCouponName;

    /**
     * 用户id
     */
    private String thirdUserId;

    /**
     * 卡号
     */
    private String cardNo;

    /**
     * 领券时间
     */
    private String drawCouponTime;

    /**
     * 核销时间
     */
    private String verificationTime;

    /**
     * 核销订单号
     */
    private String verificationOrderNum;

    /**
     * 订单总共金额
     */
    private Long orderTotalPrice;

    /**
     * 本次消费优惠金额
     */
    private Long discountAmount;

    /**
     * 支付方式
     */
    private String payChannel;

    /**
     * 核销商户号
     */
    private String verificationMch;

    /**
     * 核销来源渠道号
     */
    private String verificationChannelNo;

    /**
     * 优惠券生效时间
     */
    private String couponEffectTime;

    /**
     * 优惠券失效时间
     */
    private String couponNoEffectTime;

    /**
     * 核销人
     */
    private String verificationUser;

    /**
     * 领券用户手机号
     */
    private String drawCouponPhone;

    /**
     * 实际消费优惠金额
     */
    private Long actualConsumeDiscountAmount;

    /**
     * 最低使用消费限制
     */
    private Long lowestUsageLimit;

    /**
     * 卡bin类型
     */
    private String cardBinType;

    /**
     * 是否是银联类型
     */
    private String unionpayType;

    /**
     * 是否清算
     */
    private String clearType;

    /**
     * 清算金额
     */
    private Long clearAmount;

    /**
     * 二级分行
     */
    private String secondLevelBranch;

    /**
     * 商家补贴总金额
     */
    private Long merchantSubsidyAmount;

    /**
     * 机构补贴总金额
     */
    private Long institutionalSubsidyAmount;

    /**
     * 导入文件id
     */
    private Long uploadFileId;

    /**
     * 删除标识 （0：未删除，1：删除）默认为0
     */
    private Integer deleted;

    /**
     * 年和月份
     */
    private Long yearAndMonth;

    /**
     * 使用状态
     */
    private Integer useStatus;
}
